summaryrefslogtreecommitdiffstats
path: root/src/likeback.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/likeback.h')
-rw-r--r--src/likeback.h36
1 files changed, 18 insertions, 18 deletions
diff --git a/src/likeback.h b/src/likeback.h
index e5d383a..e319e8d 100644
--- a/src/likeback.h
+++ b/src/likeback.h
@@ -23,10 +23,10 @@
#include <ntqobject.h>
-class KConfig;
-class KAboutData;
-class KAction;
-class KActionCollection;
+class TDEConfig;
+class TDEAboutData;
+class TDEAction;
+class TDEActionCollection;
class LikeBackPrivate;
class LikeBackBar;
@@ -48,7 +48,7 @@ class LikeBackDialog;
*
* The LikeBack system has 5 components:
* @li In the application: The comment dialog, where the user write a comment, select a type of comment, etc.
* @li In the application: The KAction to plug in the Help menu. This action displays the comment dialog.
* @li In the application: The button-bar, that floats bellow titlebar of every windows of the application, and let the user to quickly show the comment dialog.
* The button-bar can be hidden.
* @li On the server: A PHP script that collects every comments that users send. The LikeBack object should be configured to contact that server.
@@ -64,7 +64,7 @@ class LikeBackDialog;
* // Comment the following line once you are sure all your windows have a name:
* likeBack->setWindowNamesListing(LikeBack::WarnUnnamedWindows);
*
- * // This line should be called early in your KMainWindow constructor because it references actionCollection().
+ * // This line should be called early in your TDEMainWindow constructor because it references actionCollection().
* // It should be called before createGUI() for the action to be plugged in the Help menu:
* likeBack->sendACommentAction(actionCollection());
* @endcode
@@ -117,18 +117,18 @@ class LikeBack : public TQObject
* The button-bar display is stored by version. On a new version, your default value will take effect again.
* This allow you to disable the button-bar once the version is stable enought to be released as final.
* @param config Set the configuration file where to store the user email address and if the button-bar should be shown.
* By default (null), the KApplication configuration object is used.
* @param aboutData Set the KAboutData instance used to get the application name and version. By default (null), the KApplication about data object is used.
* The application name is only used in the first-use information message.
* The version is used to store the button-bar visibility per version (can be shown in a development version but not in a final one...)
* and to send with the comment, so you can filter per version and know if a comment refers the latest version of the application or not.
*/
- LikeBack(Button buttons = DefaultButtons, bool showBarByDefault = false, KConfig *config = 0, const KAboutData *aboutData = 0);
+ LikeBack(Button buttons = DefaultButtons, bool showBarByDefault = false, TDEConfig *config = 0, const TDEAboutData *aboutData = 0);
/**
* Destructor.
* Also hide the button-bar, if it was shown.
* Be careful, the KAction is deleted. Do not use it afterward, and take care to unplug it before destroying this LikeBack instance.
*/
~LikeBack();
@@ -209,7 +209,7 @@ class LikeBack : public TQObject
TQ_UINT16 hostPort();
/**
* Get the KAction letting user to show the comment dialog.
* You should plug it in your Help menu, just bellow the "Report a Bug" action, or replace it.
* Adding the action below "Report a Bug" or replacing "Report a Bug" depends on your application and if you have a Bugzilla account.
* If you do not have a Bugzilla account, LikeBack is a good way for your small application to get bug reports: remove "Report a Bug".
@@ -219,7 +219,7 @@ class LikeBack : public TQObject
* <Action name="likeback_send_a_comment" />
* @endcode
*/
- KAction* sendACommentAction(KActionCollection *parent = 0);
+ TDEAction* sendACommentAction(TDEActionCollection *parent = 0);
/**
* @Returns The path of the currently active window. Each windows are separated with "~~".
@@ -280,7 +280,7 @@ class LikeBack : public TQObject
* @param windowPath The window path to send with the comment. If empty (the default), the current window path is took.
* Separate window names with "~~". For instance "MainWindow~~NewFile~~FileOpen".
* If you popup the dialog after an error occurred, you can put the error name in that field (if the window path has no sense in that context).
* When the dialog is popuped up from the sendACommentAction() KAction, this value is "HelpMenu", because there is no way to know if the user
* is commenting a thing he found/thinked about in a sub-dialog.
* @param context Not used for the moment. Will allow more fine-grained application status report.
*/
@@ -302,7 +302,7 @@ class LikeBack : public TQObject
private slots:
/**
* Slot triggered by the "Help -> Send a Comment to Developers" KAction.
* It popups the comment dialog, and set the window path to "HelpMenuAction",
* because current window path has no meaning in that case.
*/
@@ -323,16 +323,16 @@ class LikeBack : public TQObject
void setUserWantsToShowBar(bool showBar);
/**
* @Returns A pointer to the KAboutData used to determin the application name and version.
* @See The LikeBack constructor for more information.
*/
- const KAboutData *aboutData();
+ const TDEAboutData *aboutData();
/**
* @Returns A pointer to the KConfig used to store user configuration (email address, if the button-bar should be shown).
* @See The LikeBack constructor for more information.
*/
- KConfig *config();
+ TDEConfig *config();
/**
* During the first comment sending, the user is invited to enter his email address for the developers to be able to contact him back.
@@ -48,7 +48,7 @@ class LikeBackDialog;
* The LikeBack system has 5 components:
* @li In the application: The comment dialog, where the user write a comment, select a type of comment, etc.
- * @li In the application: The KAction to plug in the Help menu. This action displays the comment dialog.
+ * @li In the application: The TDEAction to plug in the Help menu. This action displays the comment dialog.
* @li In the application: The button-bar, that floats bellow titlebar of every windows of the application, and let the user to quickly show the comment dialog.
* The button-bar can be hidden.
@@ -117,18 +117,18 @@ class LikeBack : public TQObject
* This allow you to disable the button-bar once the version is stable enought to be released as final.
* @param config Set the configuration file where to store the user email address and if the button-bar should be shown.
- * By default (null), the KApplication configuration object is used.
- * @param aboutData Set the KAboutData instance used to get the application name and version. By default (null), the KApplication about data object is used.
+ * By default (null), the TDEApplication configuration object is used.
+ * @param aboutData Set the TDEAboutData instance used to get the application name and version. By default (null), the TDEApplication about data object is used.
* The application name is only used in the first-use information message.
* The version is used to store the button-bar visibility per version (can be shown in a development version but not in a final one...)
@@ -117,18 +117,18 @@ class LikeBack : public TQObject
* Destructor.
* Also hide the button-bar, if it was shown.
- * Be careful, the KAction is deleted. Do not use it afterward, and take care to unplug it before destroying this LikeBack instance.
+ * Be careful, the TDEAction is deleted. Do not use it afterward, and take care to unplug it before destroying this LikeBack instance.
*/
~LikeBack();
@@ -209,7 +209,7 @@ class LikeBack : public TQObject
TQ_UINT16 hostPort();
/**
- * Get the KAction letting user to show the comment dialog.
+ * Get the TDEAction letting user to show the comment dialog.
* You should plug it in your Help menu, just bellow the "Report a Bug" action, or replace it.
* Adding the action below "Report a Bug" or replacing "Report a Bug" depends on your application and if you have a Bugzilla account.
@@ -280,7 +280,7 @@ class LikeBack : public TQObject
* Separate window names with "~~". For instance "MainWindow~~NewFile~~FileOpen".
* If you popup the dialog after an error occurred, you can put the error name in that field (if the window path has no sense in that context).
- * When the dialog is popuped up from the sendACommentAction() KAction, this value is "HelpMenu", because there is no way to know if the user
+ * When the dialog is popuped up from the sendACommentAction() TDEAction, this value is "HelpMenu", because there is no way to know if the user
* is commenting a thing he found/thinked about in a sub-dialog.
* @param context Not used for the moment. Will allow more fine-grained application status report.
@@ -302,7 +302,7 @@ class LikeBack : public TQObject
private slots:
/**
- * Slot triggered by the "Help -> Send a Comment to Developers" KAction.
+ * Slot triggered by the "Help -> Send a Comment to Developers" TDEAction.
* It popups the comment dialog, and set the window path to "HelpMenuAction",
* because current window path has no meaning in that case.
@@ -323,16 +323,16 @@ class LikeBack : public TQObject
void setUserWantsToShowBar(bool showBar);
/**
- * @Returns A pointer to the KAboutData used to determin the application name and version.
+ * @Returns A pointer to the TDEAboutData used to determin the application name and version.
* @See The LikeBack constructor for more information.
*/
@@ -323,16 +323,16 @@ class LikeBack : public TQObject
/**
- * @Returns A pointer to the KConfig used to store user configuration (email address, if the button-bar should be shown).
+ * @Returns A pointer to the TDEConfig used to store user configuration (email address, if the button-bar should be shown).
* @See The LikeBack constructor for more information.
*/